<?php

namespace App\Http\Controllers;

use App\Models\Blog;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

class FrontendController extends Controller
{
    public function home()
    {
        return view('frontend.index');
    }
    public function about()
    {
        return view('frontend.about');
    }

    public function blogs()
    {
        // Fetch all blogs (for general listing)
        $blogs = Blog::paginate(10);  // Paginate 10 blogs per page

        // Fetch popular blogs (where popular = 1)
        $popularBlogs = Blog::where('popular', 1)->paginate(5);  // Paginate popular blogs (adjust number as needed)

        // Fetch recent blogs (order by created_at descending, most recent first)
        $recentBlogs = Blog::orderBy('created_at', 'desc')->take(5)->get();  // Get 5 recent blogs

        // Pass all variables to the view
        return view('frontend.blogs', compact('blogs', 'popularBlogs', 'recentBlogs'));
    }

    public function blogDetails($slug)
    {
        // Fetch the blog by its slug
        $blog = Blog::where('slug', $slug)->firstOrFail();  // Fetch the blog by slug

        // Fetch recent blogs (you can adjust the number based on your requirement)
        $recentBlogs = Blog::orderBy('created_at', 'desc')->take(5)->get();

        // Return the view and pass the blog data
        return view('frontend.blog-details', [
            'blog' => $blog,
            'recentBlogs' => $recentBlogs,
        ]);
    }



    public function branding()
    {
        return view('frontend.branding');
    }

    public function contact()
    {
        return view('frontend.contact');
    }

    public function digitalMarketing()
    {
        return view('frontend.digital-marketing');
    }

    public function growthMarketing()
    {
        return view('frontend.growth-marketing');
    }

    public function ourWorkApproach()
    {
        return view('frontend.our-work-approach');
    }

    public function personalLinkedIn()
    {
        return view('frontend.personal-linkedin');
    }

    public function privacyPolicy()
    {
        return view('frontend.privacy');
    }

    public function returnRefund()
    {
        return view('frontend.return-refund');
    }

    public function seo()
    {
        return view('frontend.seo');
    }

    public function services()
    {
        return view('frontend.services');
    }

    public function terms()
    {
        return view('frontend.terms');
    }

    public function ThankYou()
    {
        return view('frontend.thankyou');
    }

    public function submitContactForm(Request $request)
    {
        // Validate inputs
        $request->validate([
            'f_name'    => 'required|string|max:255',
            'f_email'   => 'required|email|max:255',  // Validate email
            'f_numb'    => 'nullable|numeric',  // Optional, validate phone as numeric
            'f_message' => 'required|string|max:5000',  // Validate message length
        ]);

        $data = [
            'name'    => $request->input('f_name'),
            'email'   => $request->input('f_email'),
            'phone'   => $request->input('f_numb'),
            'message' => $request->input('f_message')
        ];

        // Spam protection (e.g., no URLs in the message)
        if (preg_match('/http[s]?:\/\/[^\s]+/', $data['message'])) {
            return back()->with('error', 'URLs are not allowed in the message.');
        }

        // Adult content filtering (using a basic blacklist)
        $blacklist = [
            'porn',
            'sex',
            'adult',
            'buy viagra',
            'sale',
            'discount',
            'offer',
            'buy now',
            'limited time',
            'cheap',
            'special offer',
            'free',
            'clearance',
            'promotion',
            'deal',
            'bargain',
            'best price',
            'hot deal',
            'shop now',
            'buy one get one',
            'hurry up',
            'call now',
            'exclusive offer',
            'limited stock',
            'best deal',
            'big discount',
            'shop today'
        ]; // Example words, expand as necessary
        foreach ($blacklist as $word) {
            if (stripos($data['message'], $word) !== false) {
                return back()->with('error', 'Your message contains inappropriate content.');
            }
        }

        // Send Email with PHPMailer
        $mail = new PHPMailer(true);
        try {
            $mail->isSMTP();
            $mail->Host       = 'smtp.gmail.com';
            $mail->SMTPAuth   = true;
            $mail->Username   = 'web@solutionwagon.com';
            $mail->Password   = 'ifflnxphlcbtulhd';
            $mail->SMTPSecure = PHPMailer::ENCRYPTION_STARTTLS;
            $mail->Port       = 587;

            // Email settings
            $mail->setFrom('web@solutionwagon.com', 'Solution Wagon');
            $mail->addAddress('web@solutionwagon.com');

            $mail->Subject = "New Contact Form Submission";
            $mail->Body    = "Name: {$data['name']}\nEmail: {$data['email']}\nPhone: {$data['phone']}\nMessage: {$data['message']}";

            $mail->send();
        } catch (Exception $e) {
            return back()->with('error', "Message could not be sent. Mailer Error: {$mail->ErrorInfo}");
        }

        // Send data to Google Sheets
        $googleSheetUrl = "https://script.google.com/macros/s/AKfycbxzHJJ0SjwD5iLGL_lNdX9ohgXHYBEHVpXbKGBExP0LleK14PRxRGS40cdngCe_0sbbQg/exec";
        $postData = json_encode(array_merge($data, ['formType' => 'contact']));

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $googleSheetUrl);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/json']);
        curl_exec($ch);
        curl_close($ch);

        return redirect()->route('thankYou')->with('success', 'Your message has been sent!');
    }

    public function submitNewsletterForm(Request $request)
    {
        // Validate email
        $request->validate([
            'email' => 'required|email|max:255',  // Validate email
        ]);

        $email = $request->input('email');

        // Spam protection (e.g., no URLs in the email field)
        if (preg_match('/http[s]?:\/\/[^\s]+/', $email)) {
            return back()->with('error', 'URLs are not allowed in the email field.');
        }

        // Send Email with PHPMailer
        $mail = new PHPMailer(true);
        try {
            $mail->isSMTP();
            $mail->Host       = 'smtp.gmail.com';
            $mail->SMTPAuth   = true;
            $mail->Username   = 'web@solutionwagon.com';
            $mail->Password   = 'ifflnxphlcbtulhd';
            $mail->SMTPSecure = PHPMailer::ENCRYPTION_STARTTLS;
            $mail->Port       = 587;

            // Email settings
            $mail->setFrom('web@solutionwagon.com', 'Solution Wagon');
            $mail->addAddress('web@solutionwagon.com');

            $mail->Subject = "New Newsletter Subscription";
            $mail->Body    = "New subscription from: $email";

            $mail->send();
        } catch (Exception $e) {
            return back()->with('error', "Subscription could not be processed. Mailer Error: {$mail->ErrorInfo}");
        }

        // Send data to Google Sheets
        $googleSheetUrl = "https://script.google.com/macros/s/AKfycbxzHJJ0SjwD5iLGL_lNdX9ohgXHYBEHVpXbKGBExP0LleK14PRxRGS40cdngCe_0sbbQg/exec";
        $postData = json_encode(['email' => $email, 'formType' => 'newsletter']);

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $googleSheetUrl);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/json']);
        curl_exec($ch);
        curl_close($ch);

        return redirect()->route('thankYou')->with('success', 'You have subscribed successfully!');
    }
}
