@push('admin-style')
    <!-- TinyMCE CSS (No need to manually include it if you're using CDN) -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/tinymce@5.10.0/skins/ui/oxide/skin.min.css" />
@endpush

@push('admin-scripts')
    <!-- TinyMCE JS -->
    <script src="https://cdn.jsdelivr.net/npm/tinymce@5.10.0/tinymce.min.js"></script>
    <script>
        // Initialize TinyMCE editor for description field
        document.addEventListener('DOMContentLoaded', function() {
            tinymce.init({
                selector: '#description',  // Apply to the textarea with id 'description'
                height: 300,
                plugins: 'advlist autolink lists link image charmap print preview anchor',
                toolbar: 'undo redo | formatselect | forecolor backcolor| bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | link image',
                placeholder: 'Write your blog description here...'
            });
        });
    </script>
@endpush


<x-app-layout>
    <x-slot name="header">
        <h2 class="text-xl font-semibold leading-tight text-gray-800">
            {{ __('Create New Blog') }}
        </h2>
    </x-slot>

    <div class="py-12">
        <div class="mx-auto max-w-7xl sm:px-6 lg:px-8">
            <div class="overflow-hidden bg-white shadow-sm sm:rounded-lg">
                <div class="p-6 bg-white border-b border-gray-200">
                    <form method="POST" action="{{ route('admin.blogs.store') }}" enctype="multipart/form-data">
                        @csrf
                        <div class="mb-4">
                            <label for="heading" class="block text-sm font-medium text-gray-700">Heading</label>
                            <input type="text" name="heading" id="heading" class="block w-full mt-1 rounded-md shadow-sm form-input"
                                   value="{{ old('heading') }}" required autofocus />
                        </div>

                        <div class="mb-4">
                            <label for="meta_title" class="block text-sm font-medium text-gray-700">Meta Title</label>
                            <input type="text" name="meta_title" id="meta_title" class="block w-full mt-1 rounded-md shadow-sm form-input"
                                   value="{{ old('meta_title') }}" required />
                        </div>

                        <div class="mb-4">
                            <label for="meta_description" class="block text-sm font-medium text-gray-700">Meta Description</label>
                            <textarea name="meta_description" id="meta_description" rows="3" class="block w-full mt-1 rounded-md shadow-sm form-textarea"
                                      >{{ old('meta_description') }}</textarea>
                        </div>

                        <div class="mb-4">
                            <label for="meta_keywords" class="block text-sm font-medium text-gray-700">Meta Keywords</label>
                            <input type="text" name="meta_keywords" id="meta_keywords" class="block w-full mt-1 rounded-md shadow-sm form-input"
                                   value="{{ old('meta_keywords') }}" />
                        </div>

                        <div class="mb-4">
                            <label for="popular" class="block text-sm font-medium text-gray-700">Popular</label>
                            <select name="popular" id="popular" class="block w-full mt-1 rounded-md shadow-sm form-select">
                                <option value="0">No</option>
                                <option value="1">Yes</option>
                            </select>
                        </div>

                        <div class="mb-4">
                            <label for="description" class="block text-sm font-medium text-gray-700">Description</label>
                            <textarea name="description" id="description" rows="4" class="block w-full mt-1 rounded-md shadow-sm form-textarea"
                                      required>{{ old('description') }}</textarea>
                        </div>

                        <div class="mb-4">
                            <label for="slug" class="block text-sm font-medium text-gray-700">Slug</label>
                            <input type="text" name="slug" id="slug" class="block w-full mt-1 rounded-md shadow-sm form-input"
                                   value="{{ old('slug') }}" required />
                        </div>

                        <div class="mb-4">
                            <label for="main_image" class="block text-sm font-medium text-gray-700">Main Image</label>
                            <input type="file" name="main_image" id="main_image" class="block w-full mt-1 rounded-md shadow-sm form-input" />
                        </div>

                        <div class="mb-4">
                            <label for="banner_image" class="block text-sm font-medium text-gray-700">Banner Image</label>
                            <input type="file" name="banner_image" id="banner_image" class="block w-full mt-1 rounded-md shadow-sm form-input" />
                        </div>

                        <div class="flex items-center justify-end mt-4">
                            <button type="submit" class="inline-flex items-center px-4 py-2 text-xs font-semibold tracking-widest uppercase transition bg-blue-500 border border-transparent rounded-md text-blue hover:bg-blue-700 active:bg-blue-900 focus:outline-none focus:border-blue-900 focus:ring focus:ring-blue-300 disabled:opacity-25">
                                {{ __('Save') }}
                            </button>
                        </div>

                    </form>
                </div>
            </div>
        </div>
    </div>
</x-app-layout>
